Index: trunk/ippScripts/scripts/register_exp.pl
===================================================================
--- trunk/ippScripts/scripts/register_exp.pl	(revision 42986)
+++ trunk/ippScripts/scripts/register_exp.pl	(revision 43050)
@@ -62,7 +62,8 @@
     defined $exp_tag;
 
-# add -detrend UNLESS type is one of SCIENCE listed below (eg, OBJECT)
-my @SCIENCE = ( "object", "science", "light" ); # Observation types to NOT mark as detrend
-my $DETREND_FLAG = "-end_stage reg"; # Flag to use to mark detrend exposure
+# Exposures should have end stage of registration UNLESS type is one of SCIENCE listed below (eg, OBJECT)
+my @SCIENCE = ( "object", "science", "light" ); # Observation types to progress to warp
+my @DETFILTERS = ( "OPEN", "CLEAR" ); # Filters to explicitly end at registration stage (lack of detrends)
+my $END_FLAG = "-end_stage reg"; # Flag to use
 
 # setup cache interface
@@ -118,4 +119,6 @@
 my $exp_type = &value_for_flag ($cmdflags, "-exp_type");
 if (uc($exp_type) eq "NULL") { &my_die ("exp_type  not found", $exp_id, $PS_EXIT_CONFIG_ERROR); }
+
+my $filter = &value_for_flag ($cmdflags, "-filter");
 
 my ($data_group,$dist_group,$chip_workdir,$reduction);
@@ -144,5 +147,5 @@
 $command .= " $cmdflags";
 
 # Add the detrend flag, if needed
 {
     my $object = 0;             # Is it an object exposure?
@@ -152,6 +155,13 @@
             last;
         }
-    }
-    $command .= " $DETREND_FLAG" unless $object;
+    }    
+    #check against filters labeled as not progressing beyond registration
+    foreach my $detfilter (@DETFILTERS) {
+        if (lc($filter) =~ /$detfilter/) {
+            $object = 0;
+            last;
+        }
+    }
+    $command .= " $END_FLAG" unless $object;
 }
 
@@ -144,5 +147,5 @@
 $command .= " $cmdflags";
 
-# Add the detrend flag, if needed
+# Add the registration end stage flag, if needed
 {
     my $object = 0;             # Is it an object exposure?
